jupydbg
=======

unittest interactive runner and interactive stack inspection 
from jupyter notebooks

Documentation
-------------

.. On my blog: http://practicalpython.blogspot.fr/2017/07/easy-debug-with-jupyter.html
